==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/enums/MicrosoftSecurityProductName.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The alerts' productName on which the cases will be generated
 */
public enum class MicrosoftSecurityProductName(
    public val javaValue: com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName> {
    Microsoft_Cloud_App_Security(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Microsoft_Cloud_App_Security),
    Azure_Security_Center(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Security_Center),
    Azure_Advanced_Threat_Protection(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Advanced_Threat_Protection),
    Azure_Active_Directory_Identity_Protection(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Active_Directory_Identity_Protection),
    Azure_Security_Center_for_IoT(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Security_Center_for_IoT),
    ;

    override fun toJava(): com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName):
            MicrosoftSecurityProductName =
            MicrosoftSecurityProductName.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/enums/MicrosoftSecurityProductName.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The alerts' productName on which the cases will be generated
 */
public enum class MicrosoftSecurityProductName(
    public val javaValue: com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName> {
    Microsoft_Cloud_App_Security(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Microsoft_Cloud_App_Security),
    Azure_Security_Center(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Security_Center),
    Azure_Advanced_Threat_Protection(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Advanced_Threat_Protection),
    Azure_Active_Directory_Identity_Protection(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Active_Directory_Identity_Protection),
    Azure_Security_Center_for_IoT(com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName.Azure_Security_Center_for_IoT),
    ;

    override fun toJava(): com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.securityinsights.enums.MicrosoftSecurityProductName): MicrosoftSecurityProductName =
            MicrosoftSecurityProductName.values().first { it.javaValue == javaType }
    }
}
